@@ -280,7 +280,7 @@ class PrivateBucketProps(aws_cdk.aws_s3.BucketProps):
         :param website_routing_rules: Rules that define when a redirect is applied and the redirect behavior. Default: - No redirection rules.
         '''
         if isinstance(website_redirect, dict):
-            website_redirect = RedirectTarget(**website_redirect)
+            website_redirect = aws_cdk.aws_s3.RedirectTarget(**website_redirect)
         if __debug__:
             type_hints = typing.get_type_hints(PrivateBucketProps.__init__)
             check_type(argname="argument access_control", value=access_control, expected_type=type_hints["access_control"])
